% MSH_obsgrid.m
%
% AUTHOR:           Michael W. Swyer
% DATE CREATED:     2015/05/18
% DATE MODIFIED:    
% VERSION:          v.1
%
% PURPOSE:  create observation grid for Poly3D
%
% PURPOSE OF MODIFICATION:
% 
% INPUT: corners of WADGER model area
%
% OUTPUT: obs = Observation grid spaced at 2000ft x 2000ft in NAD 1983 HARN
% StatePlane Washington South FIPS 4602(US Feet) to be converted to NAD
% 1983 UTM Zone 10N in ArcMap to get bottom left corner, top right corner,
% and point spacing in meters for Poly3D.
%
% NOTE:
%
% KEY functions written specifically for this modeling:
%
% Other related functions:

clear all;close all

% WADGER obs grid
sp = 2000;
X = [1128587.03748:sp:1261920.37091];
Y = [270348.224915:sp:393264.891479];
dx = 1261920.37091 - max(X);
dy = 393264.891479 - max(Y);
X = [1128587.03748+(dx/2):sp:1261920.37091-(dx/2)];
Y = [270348.224915+(dy/2):sp:393264.891479-(dy/2)];

for i=1:numel(Y)
    for j=1:numel(X)
        obs((i-1)*numel(X)+j,1) = X(j);
        obs((i-1)*numel(X)+j,2) = Y(i);
    end
end

% plot abs grid in model area
DGERarea = [1128587.03748 270348.224915;1261920.37091 270348.224915;1261920.37091 393264.891479;1128587.03748 393264.891479;1128587.03748 270348.224915];
figure
plot(DGERarea(:,1),DGERarea(:,2),'k-')
hold on
plot(obs(:,1),obs(:,2),'k.')
axis equal